import navis
import pandas as pd
from syndb_constants.dataset import (
    CABLE_LENGTH_COLUMN_NAME,
    IS_TREE_COLUMN_NAME,
    MESH_PATH_COLUMN_NAME,
    N_BRANCHES_COLUMN_NAME,
    N_SKELETONS_COLUMN_NAME,
    N_TREES_COLUMN_NAME,
    SWB_DF_COLUMN_NAME,
)


def _swb_data_extractor(df: pd.DataFrame) -> pd.DataFrame:
    swb_data_rows = []
    for swb_path in df[SWB_DF_COLUMN_NAME]:
        tree_neuron: navis.TreeNeuron = navis.read_swc(swb_path)
        swb_data_rows.append(
            [
                tree_neuron.cable_length,
                tree_neuron.is_tree,
                tree_neuron.n_branches,
                tree_neuron.n_skeletons,
                tree_neuron.n_trees,
            ]
        )

    return pd.DataFrame(
        swb_data_rows,
        columns=[
            CABLE_LENGTH_COLUMN_NAME,
            IS_TREE_COLUMN_NAME,
            N_BRANCHES_COLUMN_NAME,
            N_SKELETONS_COLUMN_NAME,
            N_TREES_COLUMN_NAME,
        ],
    )


def _mesh_data_extractor(df: pd.DataFrame) -> pd.DataFrame:
    mesh_data_rows = []
    for mesh_path in df[MESH_PATH_COLUMN_NAME]:
        # mesh_data_rows.append()
        pass
    return pd.DataFrame(mesh_data_rows, columns=[])


def file_data_extractor(df: pd.DataFrame, mesh: bool = False, swb: bool = True) -> pd.DataFrame:
    extracted_dfs = []
    if mesh:
        raise NotImplementedError
    if swb:
        extracted_dfs.append(_swb_data_extractor(df))
    return pd.concat(extracted_dfs, axis=1)
