from typing import Iterable

from pydantic import BaseModel, FilePath
from syndb_constants.table import syndb_table_name_to_enum


class UserInfo(BaseModel):
    email: str
    access_token: str


def bool_validate_parquet_file_name(parquet_path: FilePath) -> bool:
    return parquet_path.stem.upper() in syndb_table_name_to_enum


def validate_parquet_file(parquet_path: FilePath) -> None:
    assert bool_validate_parquet_file_name(parquet_path)
    assert parquet_path.suffix == ".parquet"


def validate_parquet_files(parquet_paths: Iterable[FilePath]) -> None:
    for parquet_path in parquet_paths:
        validate_parquet_file(parquet_path)


def exception_from_bad_response(api_name: str, endpoint_name: str, exception: Exception) -> None:
    raise ValueError(f"Exception when calling {api_name} -> {endpoint_name}") from exception
